/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle;

import java.time.Instant;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.info.BuildProperties;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(RootController.PATH)
@RequiredArgsConstructor
public class RootController {

	static final String PATH = "/api"; // NOSONAR

	private final BuildProperties buildProperties;
	private final RootModelAssembler rootModelAssembler;

	@Value("${ozgcloud.stage.production:#{true}}")
	private boolean production = true;

	@GetMapping
	public EntityModel<Root> getRoot() {
		var root = Root.builder()
		  .version(getVersion())
		  .buildTime(getBuildTime())
		  .javaVersion(getJavaVersion())
		  .production(production)
		  .build();

		return rootModelAssembler.toModel(root);
	}

	private String getVersion() {
		return Objects.isNull(buildProperties) ? "--" : buildProperties.getVersion();
	}

	private Instant getBuildTime() {
		return Objects.isNull(buildProperties) ? null : buildProperties.getTime();
	}

	private String getJavaVersion() {
		return System.getProperty("java.version");
	}

}