/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.attachment;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.Future;

import org.springframework.hateoas.EntityModel;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBody;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(BinaryFileController.PATH)
@RequiredArgsConstructor
public class BinaryFileController {

	static final String PATH = "/api/binaryFiles"; // NOSONAR

	private final BinaryFileModelAssembler modelAssembler;

	@GetMapping("/{fileId}")
	public EntityModel<OzgFile> getFile(@PathVariable OzgCloudFileId fileId) {
		return modelAssembler.toModel(getMockedFile(fileId));
	}

	@PostMapping("/{vorgangId}/{field}/file")
	public Future<ResponseEntity<Void>> uploadFile(@PathVariable String vorgangId, @PathVariable String field) {
		return CompletableFuture.supplyAsync(
		  () -> ResponseEntity.created(linkTo(BinaryFileController.class).slash(OzgCloudFileId.from("TestFileId")).toUri()).build());
	}

	@GetMapping(value = "/{fileId}", produces = { MediaType.APPLICATION_OCTET_STREAM_VALUE,
	  "images/*" }, consumes = MediaType.APPLICATION_OCTET_STREAM_VALUE)
	public ResponseEntity<StreamingResponseBody> getFileData(@PathVariable OzgCloudFileId fileId) {
		return buildResponseEntity(getMockedFile(fileId), createDownloadStreamingBody());
	}

	private OzgFile getMockedFile(OzgCloudFileId id) {
		return OzgFile.builder()
		  .id(id)
		  .name("TestFileName")
		  .size(1024)
		  .contentType("text/plain")
		  .build();
	}

	private ResponseEntity<StreamingResponseBody> buildResponseEntity(OzgFile ozgFile, StreamingResponseBody responseBody) {
		return ResponseEntity.ok()
		  .header(HttpHeaders.CONTENT_DISPOSITION, String.format("attachment; filename=%s", ozgFile.name()))
		  .contentType(MediaType.APPLICATION_OCTET_STREAM)
		  .body(responseBody);
	}

	private StreamingResponseBody createDownloadStreamingBody() {
		return out -> {
			out.write("TestContent".getBytes());
			out.flush();
		};
	}

}