/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.command;

import java.time.ZonedDateTime;

import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(CommandController.PATH)
@RequiredArgsConstructor
public class CommandController {

	static final String PATH = "/api/commands"; // NOSONAR

	private final CommandModelAssembler modelAssembler;

	@GetMapping("{commandId}")
	public EntityModel<Command> getById(@PathVariable String commandId) {
		return modelAssembler.toModel(getMockedCommand(commandId));
	}

	private Command getMockedCommand(String commandId) {
		return Command.builder()
		  .id(commandId)
		  .createdAt(ZonedDateTime.now())
		  .finishedAt(ZonedDateTime.now())
		  .status(CommandStatus.FINISHED)
		  .vorgangId("TestVorgangId")
		  .order("TestOrder")
		  .errorMessage("")
		  .build();
	}

}