/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.kommentar;

import java.time.ZonedDateTime;
import java.util.List;
import java.util.stream.Stream;

import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.fachstelle.attachment.BinaryFileModelAssembler;
import de.ozgcloud.fachstelle.attachment.OzgFile;
import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(KommentarController.PATH)
@RequiredArgsConstructor
public class KommentarController {

	static final String PATH = "/api/kommentars"; // NOSONAR

	private final KommentarModelAssembler kommentarModelAssembler;
	private final BinaryFileModelAssembler binaryFileModelAssembler;

	@GetMapping("/{kommentarId}")
	public EntityModel<Kommentar> getById(@PathVariable String kommentarId) {
		return kommentarModelAssembler.toModel(getMockedKommentar(kommentarId));
	}

	private Kommentar getMockedKommentar(String id) {
		return Kommentar.builder()
		  .id(id)
		  .version(1)
		  .vorgangId("TestVorgangId")
		  .createdAt(ZonedDateTime.now())
		  .createdBy("TestName")
		  .text("TestText")
		  .attachments(List.of(OzgCloudFileId.from(id)))
		  .build();
	}

	@GetMapping("/{kommentarId}/attachments")
	public CollectionModel<EntityModel<OzgFile>> getAttachments(@PathVariable String kommentarId) {
		var attachments = Stream.of(getMockedAttachment(kommentarId));

		return binaryFileModelAssembler.toCollectionModel(attachments);
	}

	private OzgFile getMockedAttachment(String id) {
		return OzgFile.builder()
		  .id(OzgCloudFileId.from(id))
		  .name("TestFileName")
		  .size(1024)
		  .contentType("text/plain")
		  .build();
	}

	@RestController
	@RequestMapping(KommentarByVorgangController.PATH)
	@RequiredArgsConstructor
	public static class KommentarByVorgangController {

		static final String PATH = "/api/vorgangs"; // NOSONAR

		private final KommentarModelAssembler modelAssembler;

		@GetMapping("/{vorgangId}/kommentars")
		public CollectionModel<EntityModel<Kommentar>> getAll(@PathVariable String vorgangId) {
			var kommentars = Stream.of(getMockedKommentar(vorgangId));

			return modelAssembler.toCollectionModel(kommentars, vorgangId);
		}

		private Kommentar getMockedKommentar(String vorgangId) {
			return Kommentar.builder()
			  .id("TestKommentarId")
			  .version(1)
			  .vorgangId(vorgangId)
			  .createdAt(ZonedDateTime.now())
			  .createdBy("TestName")
			  .text("TestText")
			  .attachments(List.of(OzgCloudFileId.from("TestFileId")))
			  .build();
		}

	}

}