/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.registration;

import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClient;
import org.springframework.web.client.RestClientException;

import de.ozgcloud.fachstelle.security.User;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
public class FachstelleRegistrationRemoteService {

	static final String REGISTER_FACHSTELLE_URI = "api/fachstellen";

	private final RestClient restClient;
	private final FachstelleRegistrationRequestMapper requestMapper;

	boolean register(User user) {
		var request = requestMapper.toFachstelleRegistrationRequest(user);

		try {
			var response = restClient.post()
			  .uri(REGISTER_FACHSTELLE_URI)
			  .contentType(MediaType.APPLICATION_JSON)
			  .body(request)
			  .retrieve()
			  .toBodilessEntity();

			if (response.getStatusCode().is2xxSuccessful()) {
				LOG.info("Successfully registered Fachstelle {} with id {}", request.getFirmenName(), request.getMukId());
				return true;
			}

			LOG.error("Failed to register Fachstelle {} with id {}. Status code: {}", request.getFirmenName(), request.getMukId(),
			  response.getStatusCode());
		} catch (RestClientException e) {
			LOG.error("Error sending registration. {}", e.getMessage(), e);
		}

		return false;
	}

}
