/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.representation;

import java.util.stream.Stream;

import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.fachstelle.attachment.BinaryFileModelAssembler;
import de.ozgcloud.fachstelle.attachment.OzgFile;
import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(RepresentationController.PATH)
@RequiredArgsConstructor
public class RepresentationController {

	static final String PATH = "/api/representations"; // NOSONAR
	static final String PARAM_EINGANG_ID = "eingangId";

	private final BinaryFileModelAssembler modelAssembler;

	@GetMapping(params = PARAM_EINGANG_ID)
	public CollectionModel<EntityModel<OzgFile>> getAllByEingang(@RequestParam String eingangId) {
		var representations = Stream.of(getMockedRepresentation(eingangId));

		return modelAssembler.toCollectionModel(representations);
	}

	private OzgFile getMockedRepresentation(String id) {
		return OzgFile.builder()
		  .id(OzgCloudFileId.from(id))
		  .name("TestFileName")
		  .size(1024)
		  .contentType("text/plain")
		  .build();
	}

}
