/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import java.security.Security;

import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.opensaml.core.config.ConfigurationService;
import org.opensaml.xmlsec.algorithm.AlgorithmRegistry;
import org.springframework.beans.factory.InitializingBean;

public class SecurityProvider implements InitializingBean {

	@Override
	public void afterPropertiesSet() {
		Security.addProvider(new BouncyCastleProvider());

		registerSignatureAlgorithms();
	}

	private void registerSignatureAlgorithms() {
		var algorithmRegistry = ConfigurationService.get(AlgorithmRegistry.class);
		if (algorithmRegistry != null) {
			algorithmRegistry.register(new SHA256withRSAAndMGF1SignatureAlgorithm());

			ConfigurationService.register(AlgorithmRegistry.class, algorithmRegistry);
		}
	}

}
