/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import org.springframework.security.saml2.provider.service.authentication.DefaultSaml2AuthenticatedPrincipal;
import org.springframework.security.saml2.provider.service.authentication.Saml2Authentication;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;

@Component
@RequiredArgsConstructor
public class UserMapper {

	private final UserAttributeProvider userAttributeProvider;

	User map(Saml2Authentication authentication) {
		var principal = (DefaultSaml2AuthenticatedPrincipal) authentication.getPrincipal();

		return new User.UserBuilder()
		  .id(principal.getName())
		  .username(principal.getName())
		  .companyName(userAttributeProvider.getCompanyName(principal))
		  .legalForm(userAttributeProvider.getLegalForm(principal))
		  .legalFormText(userAttributeProvider.getLegalFormText(principal))
		  .registerNumber(userAttributeProvider.getRegisterNumber(principal))
		  .registerType(userAttributeProvider.getRegisterType(principal))
		  .emailAddress(userAttributeProvider.getEmailAddress(principal))
		  .address(userAttributeProvider.getAddress(authentication.getSaml2Response()))
		  .trustLevel(userAttributeProvider.getTrustLevel(principal))
		  .unknownAttributes(userAttributeProvider.getUnknownAttributes(principal))
		  .build();
	}

}
