/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import java.util.List;

import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping(VorgangController.PATH)
@RequiredArgsConstructor
public class VorgangController {

	static final String PATH = "/api/vorgangs"; // NOSONAR
	public static final String PARAM_COLLABORATION_MANAGER_ADDRESS = "addr";

	private final VorgangService vorgangService;
	private final VorgangModelAssembler modelAssembler;

	@GetMapping("/{vorgangId}")
	public EntityModel<Vorgang> getVorgang(@PathVariable String vorgangId,
	  @RequestParam(PARAM_COLLABORATION_MANAGER_ADDRESS) String collaborationManagerAddress) {
		var vorgang = vorgangService.findVorgang(vorgangId, collaborationManagerAddress);

		return modelAssembler.toModel(buildVorgangWithCollaborationManagerAddress(vorgang, collaborationManagerAddress));
	}

	@GetMapping
	public CollectionModel<EntityModel<Vorgang>> getAll() {
		return modelAssembler.toCollectionModel(List.of());
	}

	private VorgangWithCollaborationManagerAddress buildVorgangWithCollaborationManagerAddress(Vorgang vorgang, String collaborationManagerAddress) {
		return VorgangWithCollaborationManagerAddress.builder()
		  .vorgang(vorgang)
		  .collaborationManagerAddress(collaborationManagerAddress)
		  .build();
	}

}