/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.server.RepresentationModelAssembler;
import org.springframework.stereotype.Component;

import de.ozgcloud.fachstelle.common.ModelBuilder;

@Component
class VorgangModelAssembler implements RepresentationModelAssembler<VorgangWithCollaborationManagerAddress, EntityModel<Vorgang>> {

	static final String REL_VORGANG_MIT_EINGANG = "vorgang-mit-eingang";

	@Override
	public EntityModel<Vorgang> toModel(VorgangWithCollaborationManagerAddress vorgangWithCollaborationManagerAddress) {
		var vorgang = vorgangWithCollaborationManagerAddress.vorgang();
		var selfLink = linkTo(
		  methodOn(VorgangController.class).getVorgang(vorgang.id(), vorgangWithCollaborationManagerAddress.collaborationManagerAddress()));

		return ModelBuilder.fromEntity(vorgang)
		  .addLink(selfLink.withSelfRel())
		  .addLink(selfLink.withRel(REL_VORGANG_MIT_EINGANG))
		  .buildModel();
	}

}