/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import java.util.Objects;

import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.LinkRelation;
import org.springframework.hateoas.server.RepresentationModelProcessor;
import org.springframework.stereotype.Component;

import de.ozgcloud.fachstelle.common.ModelBuilder;

@Component
class VorgangProcessor implements RepresentationModelProcessor<EntityModel<Vorgang>> {

	static final LinkRelation REL_KOMMENTARE = LinkRelation.of("kommentare");
	static final LinkRelation REL_ATTACHMENTS = LinkRelation.of("attachments");
	static final LinkRelation REL_DOWNLOAD_ATTACHMENTS = LinkRelation.of("downloadAttachments");
	static final LinkRelation REL_REPRESENTATIONS = LinkRelation.of("representations");
	static final LinkRelation REL_HISTORIE = LinkRelation.of("historie");

	// private static final Predicate<Vorgang> HAS_ATTACHMENTS = vorgang -> vorgang.eingang().numberOfAttachments() > 0;
	// private static final Predicate<Vorgang> HAS_REPRESENTATIONS = vorgang -> vorgang.eingang().numberOfRepresentations() > 0;

	@Override
	public EntityModel<Vorgang> process(EntityModel<Vorgang> model) {
		var vorgang = model.getContent();

		if (Objects.isNull(vorgang)) {
			return model;
		}

		return ModelBuilder.fromModel(model)
		  // .addLink(linkTo(KommentarController.KommentarByVorgangController.class).slash(vorgang.id()).slash("kommentars").withRel(REL_KOMMENTARE))
		  // .ifMatch(HAS_ATTACHMENTS)
		  // .addLinks(linkTo(methodOn(AttachmentController.class).getAllByEingang(vorgang.eingang().id())).withRel(REL_ATTACHMENTS),
		  // linkTo(methodOn(AttachmentController.AttachmentsByVorgangController.class).download(vorgang.id(), vorgang.eingang().id())).withRel(
		  // REL_DOWNLOAD_ATTACHMENTS))
		  // .ifMatch(HAS_REPRESENTATIONS)
		  // .addLink(linkTo(methodOn(RepresentationController.class).getAllByEingang(vorgang.eingang().id())).withRel(REL_REPRESENTATIONS))
		  // .addLink(linkTo(methodOn(HistorieController.class).getAll(vorgang.id())).withRel(REL_HISTORIE))
		  .buildModel();
	}

}