/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestClient;
import org.springframework.web.util.UriTemplate;

import de.ozgcloud.fachstelle.FachstellenProxyProperties;
import de.ozgcloud.fachstelle.proxy.CollaborationGrpcFindVorgangResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@RequiredArgsConstructor
@Component
class VorgangRemoteService {

    public static final String DUMMY_SAML_TOKEN = "--dummy-saml-token--";
    static final String FIND_VORGANG_URI = "/api/vorgang/{vorgangId}/{samlToken}";

    private final RestClient fachstellenProxyClient;
    private final FachstellenProxyProperties fachstellenProxyProperties;
    private final VorgangMapper vorgangMapper;

    Vorgang findVorgang(String id, String collaborationManagerAddress) {
        var response = fachstellenProxyClient.get().uri(buildFindVorgangUri(id))
                .accept(MediaType.APPLICATION_JSON)
                .header(fachstellenProxyProperties.getCollaborationManagerAddressHeader(), collaborationManagerAddress)
                .retrieve()
                .toEntity(CollaborationGrpcFindVorgangResponse.class)
                .getBody();

        if (response == null) {
            throw new IllegalStateException("Received null vorgang response");
        }

        return buildVorgangResponse(response);
    }

    String buildFindVorgangUri(String vorgangId) {
        return new UriTemplate(FIND_VORGANG_URI).expand(vorgangId, DUMMY_SAML_TOKEN).toString();
    }

    private Vorgang buildVorgangResponse(CollaborationGrpcFindVorgangResponse response) {
        return vorgangMapper.toVorgang(response.getVorgang());
    }

}
