/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class EnvironmentControllerTest {

	@Spy
	@InjectMocks
	private EnvironmentController environmentController;

	@Mock
	private OAuth2Properties oAuth2Properties;

	@Test
	void shouldHaveEnvironment() {
		assertThat(environmentController.getEnvironment()).isNotNull();
	}

	@Test
	void shouldHaveProduction() {
		assertThat(environmentController.getEnvironment().production()).isTrue();
	}

	@Test
	void shouldHaveFachstelle() {
		assertThat(environmentController.getEnvironment().fachstelle()).isTrue();
	}

	@Test
	void shouldHaveRemoteHost() {
		assertThat(environmentController.getEnvironment().remoteHost()).isEqualTo("/api");
	}

	@Test
	void shouldHaveAuthServer() {
		when(oAuth2Properties.getAuthServerUrl()).thenReturn("TestAuthServerUrl");

		assertThat(environmentController.getEnvironment().authServer()).isEqualTo("TestAuthServerUrl");
	}

	@Test
	void shouldHaveClientId() {
		when(oAuth2Properties.getResource()).thenReturn("TestClientId");

		assertThat(environmentController.getEnvironment().clientId()).isEqualTo("TestClientId");
	}

	@Test
	void shouldHaveRealm() {
		when(oAuth2Properties.getRealm()).thenReturn("TestRealm");

		assertThat(environmentController.getEnvironment().realm()).isEqualTo("TestRealm");
	}

}