/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Spy;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.IanaLinkRelations;
import org.springframework.hateoas.Link;

class RootModelAssemblerTest {

	@Spy
	private RootModelAssembler assembler = new RootModelAssembler();

	@Nested
	class TestToModel {

		@Test
		void shouldHaveSelfLink() {
			var link = toModel().getLink(IanaLinkRelations.SELF_VALUE);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(RootController.PATH);
		}

		@Test
		void shouldHaveVorgangAllLink() {
			var link = toModel().getLink(RootModelAssembler.ALL_VORGAENGE_REL);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(RootController.PATH + "/vorgangs");
		}

		private EntityModel<Root> toModel() {
			return assembler.toModel(RootTestFactory.create());
		}

	}

}