/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.attachment;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;

import de.ozgcloud.fachstelle.vorgang.EingangTestFactory;
import de.ozgcloud.fachstelle.vorgang.VorgangTestFactory;
import lombok.SneakyThrows;

@ExtendWith(MockitoExtension.class)
class AttachmentsByVorgangControllerTest {

	@Spy
	private AttachmentController.AttachmentsByVorgangController controller;

	private MockMvc mockMvc;

	@BeforeEach
	void init() {
		mockMvc = MockMvcBuilders.standaloneSetup(controller).build();
	}

	@Nested
	class TestDownload {

		@BeforeEach
		void init() {
			doReturn(OzgFileTestFactory.NAME).when(controller).buildZipName();
		}

		@SneakyThrows
		@Test
		void shouldReturnStatusOk() {
			performRequest().andExpect(status().isOk());
		}

		@SneakyThrows
		@Test
		void shouldBuildZipName() {
			performRequest();

			verify(controller).buildZipName();
		}

		@SneakyThrows
		@Test
		void shouldHaveContentDispositionHeader() {
			performRequest().andExpect(header().string(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=" + OzgFileTestFactory.NAME));
		}

		@SneakyThrows
		@Test
		void shouldHaveContentType() {
			performRequest().andExpect(header().string(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_OCTET_STREAM_VALUE));
		}

		@SneakyThrows
		@Test
		void shouldWriteZipFile() {
			performRequest();

			verify(controller).createZipFile(any(), eq(EingangTestFactory.ID));
		}

		@SneakyThrows
		private ResultActions performRequest() {
			return mockMvc.perform(asyncDispatch(mockMvc.perform(get(
			  AttachmentController.AttachmentsByVorgangController.PATH.replace("{vorgangId}", VorgangTestFactory.ID) + "?eingangId="
				+ EingangTestFactory.ID).header(HttpHeaders.ACCEPT, MediaType.APPLICATION_OCTET_STREAM_VALUE)).andReturn()));
		}

	}

	@Nested
	class TestBuildZipName {

		@Test
		void shouldReturnFileName() {
			assertThat(controller.buildZipName()).isEqualTo("TestVorgangNummer_Anhaenge.zip");
		}

	}

}
