/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.command;

import static org.springframework.security.test.web.servlet.request.SecurityMockMvcRequestPostProcessors.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.nio.charset.Charset;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.http.MediaType;
import org.springframework.test.context.TestPropertySource;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;

import lombok.SneakyThrows;

@RunWith(SpringRunner.class)
@SpringBootTest
@AutoConfigureMockMvc(addFilters = false, printOnlyOnFailure = false)
@TestPropertySource(properties = {
        "ozgcloud.fachstelle.logout-success-url=http://logout",
        "ozgcloud.fachstelle.login-redirect-url=http://login",
        "ozgcloud.fachstelle.cors=http://login;http://saml-idp",
        "ozgcloud.fachstellen-proxy.base-url=http://proxy",
        "keycloak.auth-server-url=http://keycloak",
        "keycloak.realm=fachstelle",
        "spring.security.saml2.relyingparty.registration.muk.entity-id=http://mock-idp",
        "spring.security.saml2.relyingparty.registration.muk.signing.credentials[0].private-key-location=classpath:/mujina-test.key",
        "spring.security.saml2.relyingparty.registration.muk.signing.credentials[0].certificate-location=classpath:/mujina-test.crt",
        "spring.security.saml2.relyingparty.registration.muk.decryption.credentials[0].private-key-location=classpath:/mujina-test.key",
        "spring.security.saml2.relyingparty.registration.muk.decryption.credentials[0].certificate-location=classpath:/mujina-test.crt",
        "spring.security.saml2.relyingparty.registration.muk.assertingparty.singlesignon.sign-request=false",
        "spring.security.saml2.relyingparty.registration.muk.assertingparty.metadata-uri=classpath:/metadata.xml"
})
@Disabled("need to refactor: The keyfile mujina-test.key is empty")
class CommandControllerITCase {

    @Autowired
    private MockMvc mockMvc;

    @SneakyThrows
    @Test
    void shouldReturnStatusOk() {
        performRequest().andExpect(status().isOk());
    }

    @SneakyThrows
    @Test
    void shouldHaveId() {
        performRequest().andExpect(jsonPath("$.id").value(CommandTestFactory.ID));
    }

    @SneakyThrows
    @Test
    void shouldHaveCreatedAt() {
        performRequest().andExpect(jsonPath("$.createdAt").exists());
    }

    @SneakyThrows
    @Test
    void shouldHaveFinishedAt() {
        performRequest().andExpect(jsonPath("$.finishedAt").exists());
    }

    @SneakyThrows
    @Test
    void shouldHaveStatus() {
        performRequest().andExpect(jsonPath("$.status").value(CommandStatus.FINISHED.toString()));
    }

    @SneakyThrows
    @Test
    void shouldHaveVorgangId() {
        performRequest().andExpect(jsonPath("$.vorgangId").value("TestVorgangId"));
    }

    @SneakyThrows
    @Test
    void shouldHaveOrder() {
        performRequest().andExpect(jsonPath("$.order").value("TestOrder"));
    }

    @SneakyThrows
    @Test
    void shouldHaveErrorMessage() {
        performRequest().andExpect(jsonPath("$.errorMessage").value(""));
    }

    @SneakyThrows
    @Test
    void shouldHaveLinks() {
        performRequest().andExpect(jsonPath("$._links").exists());
    }

    @SneakyThrows
    private ResultActions performRequest() {
        return mockMvc.perform(get(CommandController.PATH + "/" + CommandTestFactory.ID).contentType(MediaType.APPLICATION_JSON)
                .characterEncoding(Charset.defaultCharset()).with(csrf().asHeader()));
    }

}