/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.historie;

import static org.assertj.core.api.Assertions.*;

import java.util.stream.Stream;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.hateoas.IanaLinkRelations;
import org.springframework.hateoas.Link;

import de.ozgcloud.fachstelle.command.CommandTestFactory;

@ExtendWith(MockitoExtension.class)
class HistorieModelAssemblerTest {

	@Spy
	private HistorieModelAssembler modelAssembler;

	@Nested
	class TestToModel {

		@Test
		void shouldHaveSelfLink() {
			var link = modelAssembler.toModel(CommandTestFactory.create()).getLink(IanaLinkRelations.SELF_VALUE);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(HistorieController.PATH + "/" + CommandTestFactory.ID);
		}

	}

	@Nested
	class TestToCollectionModel {

		@Test
		void shouldHaveSelfLink() {
			var link = modelAssembler.toCollectionModel(Stream.of(CommandTestFactory.create())).getLink(IanaLinkRelations.SELF);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(HistorieController.PATH);
		}

	}

}