/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.kommentar;

import static org.springframework.security.test.web.servlet.request.SecurityMockMvcRequestPostProcessors.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.nio.charset.Charset;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.http.MediaType;
import org.springframework.test.context.TestPropertySource;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.ResultActions;

import lombok.SneakyThrows;

@RunWith(SpringRunner.class)
@SpringBootTest
@AutoConfigureMockMvc(addFilters = false, printOnlyOnFailure = false)
@TestPropertySource(properties = {
		"ozgcloud.fachstelle.logout-success-url=http://logout",
		"ozgcloud.fachstelle.login-redirect-url=http://login",
		"ozgcloud.fachstelle.cors=http://login;http://saml-idp",
		"ozgcloud.fachstellen-proxy.base-url=http://proxy",
		"keycloak.auth-server-url=http://keycloak",
		"keycloak.realm=fachstelle",
		"spring.security.saml2.relyingparty.registration.muk.entity-id=http://mock-idp",
		"spring.security.saml2.relyingparty.registration.muk.signing.credentials[0].private-key-location=classpath:/mujina-test.key",
		"spring.security.saml2.relyingparty.registration.muk.signing.credentials[0].certificate-location=classpath:/mujina-test.crt",
		"spring.security.saml2.relyingparty.registration.muk.decryption.credentials[0].private-key-location=classpath:/mujina-test.key",
		"spring.security.saml2.relyingparty.registration.muk.decryption.credentials[0].certificate-location=classpath:/mujina-test.crt",
		"spring.security.saml2.relyingparty.registration.muk.assertingparty.singlesignon.sign-request=false",
		"spring.security.saml2.relyingparty.registration.muk.assertingparty.metadata-uri=classpath:/metadata.xml"
})
@Disabled("need to refactor: The keyfile mujina-test.key is empty")
class KommentarControllerITCase {

	@Autowired
	private MockMvc mockMvc;

	@Nested
	class TestGetById {

		@SneakyThrows
		@Test
		void shouldReturnStatusOk() {
			performRequest().andExpect(status().isOk());
		}

		@SneakyThrows
		@Test
		void shouldHaveId() {
			performRequest().andExpect(jsonPath("$.id").value(KommentarTestFactory.ID));
		}

		@SneakyThrows
		@Test
		void shouldHaveVersion() {
			performRequest().andExpect(jsonPath("$.version").value(1));
		}

		@SneakyThrows
		@Test
		void shouldHaveVorgangId() {
			performRequest().andExpect(jsonPath("$.vorgangId").value("TestVorgangId"));
		}

		@SneakyThrows
		@Test
		void shouldHaveCreatedAt() {
			performRequest().andExpect(jsonPath("$.createdAt").exists());
		}

		@SneakyThrows
		@Test
		void shouldHaveCreatedBy() {
			performRequest().andExpect(jsonPath("$.createdBy").value("TestName"));
		}

		@SneakyThrows
		@Test
		void shouldHaveText() {
			performRequest().andExpect(jsonPath("$.text").value("TestText"));
		}

		@SneakyThrows
		@Test
		void shouldHaveAttachments() {
			performRequest().andExpect(jsonPath("$.attachments").exists());
		}

		@SneakyThrows
		@Test
		void shouldHaveLinks() {
			performRequest().andExpect(jsonPath("$._links").exists());
		}

		@SneakyThrows
		private ResultActions performRequest() {
			return mockMvc.perform(
					get(KommentarController.PATH + "/" + KommentarTestFactory.ID)
							.contentType(MediaType.APPLICATION_JSON).characterEncoding(Charset.defaultCharset())
							.with(csrf().asHeader()));
		}

	}

	@Nested
	class TestGetAttachments {

		@SneakyThrows
		@Test
		void shouldReturnStatusOk() {
			performRequest().andExpect(status().isOk());
		}

		@SneakyThrows
		@Test
		void shouldHaveContent() {
			performRequest().andExpect(jsonPath("$._embedded").exists());
		}

		@SneakyThrows
		@Test
		void shouldHaveLinks() {
			performRequest().andExpect(jsonPath("$._links").exists());
		}

		@SneakyThrows
		@Test
		void shouldHaveCommandList() {
			performRequest().andExpect(jsonPath("$._embedded.ozgFileList").exists());
		}

		@SneakyThrows
		@Test
		void shouldHaveId() {
			performRequest().andExpect(jsonPath("$._embedded.ozgFileList[0].id.value").value(KommentarTestFactory.ID));
		}

		@SneakyThrows
		@Test
		void shouldHaveName() {
			performRequest().andExpect(jsonPath("$._embedded.ozgFileList[0].name").value("TestFileName"));
		}

		@SneakyThrows
		@Test
		void shouldHaveSize() {
			performRequest().andExpect(jsonPath("$._embedded.ozgFileList[0].size").value(1024));
		}

		@SneakyThrows
		@Test
		void shouldHaveContentType() {
			performRequest().andExpect(jsonPath("$._embedded.ozgFileList[0].contentType").value("text/plain"));
		}

		@SneakyThrows
		private ResultActions performRequest() {
			return mockMvc.perform(
					get(KommentarController.PATH + "/" + KommentarTestFactory.ID + "/attachments")
							.contentType(MediaType.APPLICATION_JSON).characterEncoding(Charset.defaultCharset())
							.with(csrf().asHeader()));
		}

	}

}
