/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.kommentar;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;

import de.ozgcloud.fachstelle.attachment.BinaryFileModelAssembler;
import de.ozgcloud.fachstelle.attachment.OzgFileTestFactory;

@ExtendWith(MockitoExtension.class)
class KommentarControllerTest {

	@Spy
	@InjectMocks
	private KommentarController controller;

	@Mock
	private KommentarModelAssembler kommentarModelAssembler;

	@Mock
	private BinaryFileModelAssembler binaryFileModelAssembler;

	@Nested
	class TestGetById {

		@BeforeEach
		void init() {
			when(kommentarModelAssembler.toModel(any())).then(i -> EntityModel.of(i.getArgument(0)));
		}

		@Test
		void shouldCallAssembler() {
			controller.getById("");

			verify(kommentarModelAssembler).toModel(any());
		}

		@Test
		void shouldHaveKommentarEntityModel() {
			assertThat(controller.getById("")).isNotNull();
		}

		@Test
		void shouldHaveKommentar() {
			assertThat(controller.getById("").getContent()).isNotNull();
		}

	}

	@Nested
	class TestGetAttachments {

		@BeforeEach
		void init() {
			when(binaryFileModelAssembler.toCollectionModel(any(Stream.class))).thenReturn(
			  CollectionModel.of(List.of(EntityModel.of(OzgFileTestFactory.create()))));
		}

		@Test
		void shouldCallAssembler() {
			controller.getAttachments("");

			verify(binaryFileModelAssembler).toCollectionModel(any(Stream.class));
		}

		@Test
		void shouldHaveAttachmentCollectionModel() {
			assertThat(controller.getAttachments("")).isNotNull();
		}

		@Test
		void shouldHaveAttachmentEntityModel() {
			assertThat(controller.getAttachments("").getContent().stream().findFirst()).isPresent();
		}

		@Test
		void shouldHaveAttachment() {
			assertThat(controller.getAttachments("").getContent().stream().findFirst().map(EntityModel::getContent)).isPresent();
		}

	}

}
