/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.registration;

import static de.ozgcloud.fachstelle.registration.FachstelleRegistrationRemoteService.*;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.client.RestClient;

import de.ozgcloud.fachstelle.security.User;
import de.ozgcloud.fachstelle.security.UserTestFactory;

@ExtendWith(MockitoExtension.class)
class FachstelleRegistrationRemoteServiceTest {

	@Spy
	@InjectMocks
	private FachstelleRegistrationRemoteService service;

	@Mock
	private RestClient restClient;

	@Mock
	private FachstelleRegistrationRequestMapper requestMapper;

	@Nested
	class TestRegister {
		private static final User user = UserTestFactory.create();

		private RestClient.ResponseSpec responseSpec;

		@BeforeEach
		void setUp() {
			var request = GrpcFachstelleRegistrationRequestTestFactory.create();
			var uriSpec = mock(RestClient.RequestBodyUriSpec.class);
			var bodySpec = mock(RestClient.RequestBodySpec.class);
			responseSpec = mock(RestClient.ResponseSpec.class);

			when(requestMapper.toFachstelleRegistrationRequest(user)).thenReturn(request);
			when(restClient.post()).thenReturn(uriSpec);
			when(uriSpec.uri(REGISTER_FACHSTELLE_URI)).thenReturn(bodySpec);
			when(bodySpec.contentType(MediaType.APPLICATION_JSON)).thenReturn(bodySpec);
			when(bodySpec.body(request)).thenReturn(bodySpec);
			when(bodySpec.retrieve()).thenReturn(responseSpec);
		}

		@Test
		void shouldCallRestClient() {
			when(responseSpec.toBodilessEntity()).thenReturn(new ResponseEntity<>(HttpStatus.OK));

			service.register(user);

			verify(restClient).post();
		}

		@Test
		void shouldCallRequestMapper() {
			when(responseSpec.toBodilessEntity()).thenReturn(new ResponseEntity<>(HttpStatus.OK));

			service.register(user);

			verify(requestMapper).toFachstelleRegistrationRequest(user);
		}

		@Test
		void shouldRegisterSuccessfully() {
			when(responseSpec.toBodilessEntity()).thenReturn(new ResponseEntity<>(HttpStatus.OK));

			var result = service.register(user);
			assertTrue(result);
		}

		@Test
		void shouldHaveRegistrationError() {
			when(responseSpec.toBodilessEntity()).thenReturn(new ResponseEntity<>(HttpStatus.INTERNAL_SERVER_ERROR));

			var result = service.register(user);
			assertFalse(result);
		}
	}

}