/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.registration;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import de.ozgcloud.fachstelle.security.User;
import de.ozgcloud.fachstelle.security.UserTestFactory;

@ExtendWith(MockitoExtension.class)
class FachstelleRegistrationServiceTest {
	@InjectMocks
	private FachstelleRegistrationService service;

	@Mock
	private FachstelleRegistrationRemoteService remoteService;

	@Nested
	class TestRegister {
		private static final User user = UserTestFactory.create();

		@BeforeEach
		void init() {
			when(remoteService.register(user)).thenReturn(true);
		}

		@Test
		void shouldCallRemoteService() {
			service.register(user);

			verify(remoteService).register(user);
		}

		@Test
		void shouldReturnRegistrationResult() {
			var result = service.register(user);

			assertTrue(result);
		}
	}
}