/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.resource;

import static de.ozgcloud.fachstelle.resource.OzgcloudResourceController.*;
import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;

import de.ozgcloud.fachstelle.Root;
import de.ozgcloud.fachstelle.RootTestFactory;

class OzgcloudResourceRootProcessorTest {

	private final OzgcloudResourceRootProcessor processor = new OzgcloudResourceRootProcessor();

	@Nested
	class TestProcess {

		private final EntityModel<Root> model = EntityModel.of(RootTestFactory.create());

		@Test
		void shouldReturnOriginalModel() {
			var result = processor.process(model);

			assertThat(result).isEqualTo(model);
		}

		@Test
		void shouldAddResourceLink() {
			processor.process(model);

			assertThat(model.getLink(OzgcloudResourceRootProcessor.REL_RESOURCE)).isPresent().get().extracting(Link::getHref)
			  .isEqualTo(OzgcloudResourceController.PATH + "?" + PARAM_URI + "={uri}");
		}

	}

}


