/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import static de.ozgcloud.fachstelle.security.SHA256withRSAAndMGF1SignatureAlgorithm.*;
import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;
import org.opensaml.xmlsec.algorithm.AlgorithmDescriptor;

class SHA256withRSAAndMGF1SignatureAlgorithmTest {

	@Test
	void shouldGetKey() {
		var algorithm = new SHA256withRSAAndMGF1SignatureAlgorithm();

		assertThat(algorithm.getKey()).isEqualTo(RSA_ALGORITHM_ID);
	}

	@Test
	void shouldGetURI() {
		var algorithm = new SHA256withRSAAndMGF1SignatureAlgorithm();

		assertThat(algorithm.getURI()).isEqualTo(RSA_SHA256_MGF1_ALGORITHM_URL);
	}

	@Test
	void shouldGetType() {
		var algorithm = new SHA256withRSAAndMGF1SignatureAlgorithm();

		assertThat(algorithm.getType()).isEqualTo(AlgorithmDescriptor.AlgorithmType.Signature);
	}

	@Test
	void shouldGetJCAAlgorithmID() {
		var algorithm = new SHA256withRSAAndMGF1SignatureAlgorithm();

		assertThat(algorithm.getJCAAlgorithmID()).isEqualTo(RSA_SHA256_MGF1_ALGORITHM_ID);
	}

	@Test
	void shouldGetDigest() {
		var algorithm = new SHA256withRSAAndMGF1SignatureAlgorithm();

		assertThat(algorithm.getDigest()).isEqualTo(SHA256_ALGORITHM_ID);
	}

}