/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;
import org.opensaml.core.config.ConfigurationService;
import org.opensaml.core.config.InitializationException;
import org.opensaml.core.xml.config.XMLObjectProviderRegistry;
import org.opensaml.core.xml.io.UnmarshallerFactory;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.saml.saml2.core.Assertion;
import org.opensaml.saml.saml2.core.Attribute;
import org.opensaml.saml.saml2.core.AttributeStatement;
import org.opensaml.saml.saml2.core.EncryptedAssertion;
import org.opensaml.saml.saml2.core.Response;
import org.opensaml.saml.saml2.core.impl.ResponseUnmarshaller;
import org.opensaml.saml.saml2.encryption.Decrypter;
import org.opensaml.xmlsec.encryption.support.DecryptionException;
import org.springframework.core.io.ClassPathResource;

@ExtendWith(MockitoExtension.class)
@Disabled("need to refactor: The keyfile mujina-test.key is empty")
class Saml2DecrypterTest {

	private Saml2Decrypter saml2Decrypter;
	private String samlResponse;

	@BeforeEach
	void init() throws NoSuchFieldException, IllegalAccessException, InitializationException {
		saml2Decrypter = new Saml2Decrypter();

		var privateKeyLocationField = Saml2Decrypter.class.getDeclaredField("decryptionPrivateKeyLocation");
		privateKeyLocationField.setAccessible(true);
		privateKeyLocationField.set(saml2Decrypter, new ClassPathResource("mujina-test.key"));

		var certificateLocationField = Saml2Decrypter.class.getDeclaredField("decryptionCertificateLocation");
		certificateLocationField.setAccessible(true);
		certificateLocationField.set(saml2Decrypter, new ClassPathResource("mujina-test.crt"));

		saml2Decrypter.init();
	}

	@Nested
	class TestInit {

		@Test
		void shouldHaveDecrypter() {
			assertThat(saml2Decrypter.getDecrypter()).isNotNull();
		}

	}

	@Nested
	class TestGetDecryptedAttribute {

		private static final String ATTRIBUTE_NAME = "TestAttributeName";

		@Mock
		private UnmarshallerFactory unmarshallerFactory;

		@Mock
		private ResponseUnmarshaller responseUnmarshaller;

		@Mock
		private XMLObjectProviderRegistry providerRegistry;

		@Mock
		private Response response;

		@Mock
		private EncryptedAssertion encryptedAssertion;

		@Mock
		private Decrypter decrypter;

		@Mock
		private AttributeStatement attributeStatement;

		@Mock
		private Attribute attribute;

		@Mock
		private Assertion assertion;

		@BeforeEach
		void init() throws IOException, UnmarshallingException, DecryptionException {
			samlResponse = FileUtils.readFileToString(new File("src/test/resources/SamlResponse.xml"), Charset.defaultCharset());

			when(decrypter.decrypt(encryptedAssertion)).thenReturn(assertion);
			when(attribute.getName()).thenReturn(ATTRIBUTE_NAME);
			when(assertion.getStatements()).thenReturn(List.of(attributeStatement, attributeStatement));
			when(attributeStatement.getAttributes()).thenReturn(Collections.singletonList(attribute));
			when(response.getEncryptedAssertions()).thenReturn(Collections.singletonList(encryptedAssertion));
			when(response.getAssertions()).thenReturn(new ArrayList<>(Collections.singletonList(assertion)));

			when(responseUnmarshaller.unmarshall(any())).thenReturn(response);
			when(unmarshallerFactory.getUnmarshaller(Response.DEFAULT_ELEMENT_NAME)).thenReturn(responseUnmarshaller);
			when(providerRegistry.getUnmarshallerFactory()).thenReturn(unmarshallerFactory);

			saml2Decrypter.setDecrypter(decrypter);
		}

		@Test
		void shouldDecryptAttribute() {
			try (var configService = mockStatic(ConfigurationService.class)) {
				configService.when(() -> ConfigurationService.get(XMLObjectProviderRegistry.class)).thenReturn(providerRegistry);

				var attribute = saml2Decrypter.getDecryptedAttribute(samlResponse, ATTRIBUTE_NAME);

				assertThat(attribute).isNotNull();
			}
		}

	}

}