/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import static de.ozgcloud.fachstelle.security.SecurityExceptionHandler.*;
import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpSession;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class SecurityExceptionHandlerTest {

	SecurityExceptionHandler exceptionHandler = new SecurityExceptionHandler();
	@Mock
	HttpServletRequest request;
	@Mock
	SecurityException exception;
	@Mock
	HttpSession session;

	@BeforeEach
	void setUp() {
		when(request.getSession()).thenReturn(session);
	}

	@Test
	void shouldCreateNotFoundView() {
		var res = exceptionHandler.handleSecurityException(request, exception);

		assertThat(res).isNotNull();
	}

	@Test
	void shouldHaveMessage() {
		when(exception.getMessage()).thenReturn("message");

		var res = exceptionHandler.handleSecurityException(request, exception);

		assertThat(res.getModel()).containsEntry("exception", "message");
	}

	@Test
	void shouldHaveUrl() {
		var val = new StringBuffer("http://localhost:8080/");
		when(request.getRequestURL()).thenReturn(val);

		var res = exceptionHandler.handleSecurityException(request, exception);

		assertThat(res.getModel()).containsEntry("url", val);
	}

	@Test
	void shouldHaveViewName() {
		var res = exceptionHandler.handleSecurityException(request, exception);

		assertThat(res.getViewName()).isEqualTo(DEFAULT_ERROR_VIEW);
	}

	@Test
	void shouldInvalidateSession() {
		exceptionHandler.handleSecurityException(request, exception);

		verify(session).invalidate();
	}

}