/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.Collections;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.security.saml2.provider.service.authentication.DefaultSaml2AuthenticatedPrincipal;
import org.springframework.security.saml2.provider.service.authentication.Saml2Authentication;

@ExtendWith(MockitoExtension.class)
class UserMapperTest {

	@Spy
	@InjectMocks
	private UserMapper userMapper;

	@Mock
	private UserAttributeProvider userAttributeProvider;

	private Saml2Authentication auth;

	@BeforeEach
	void setup() {
		auth = mock(Saml2Authentication.class);
		var principal = new DefaultSaml2AuthenticatedPrincipal(UserTestFactory.USER_ID, Collections.emptyMap());
		when(auth.getPrincipal()).thenReturn(principal);
		when(auth.getSaml2Response()).thenReturn("");

		when(userAttributeProvider.getCompanyName(principal)).thenReturn(UserTestFactory.COMPANY_NAME);
		when(userAttributeProvider.getLegalForm(principal)).thenReturn(UserTestFactory.LEGAL_FORM);
		when(userAttributeProvider.getLegalFormText(principal)).thenReturn(UserTestFactory.LEGAL_FORM_TEXT);
		when(userAttributeProvider.getRegisterNumber(principal)).thenReturn(UserTestFactory.REGISTER_NUMBER);
		when(userAttributeProvider.getRegisterType(principal)).thenReturn(UserTestFactory.REGISTER_TYPE);
		when(userAttributeProvider.getEmailAddress(principal)).thenReturn(UserTestFactory.EMAIL_ADDRESS);
		when(userAttributeProvider.getAddress("")).thenReturn(UserTestFactory.ADDRESS);
		when(userAttributeProvider.getTrustLevel(principal)).thenReturn(UserTestFactory.TRUST_LEVEL);
		when(userAttributeProvider.getUnknownAttributes(principal)).thenReturn(Collections.emptyList());
	}

	@Test
	void shouldGetId() {
		var user = userMapper.map(auth);

		assertThat(user.getId()).isEqualTo(UserTestFactory.USER_ID);
	}

	@Test
	void shouldGetUsername() {
		var user = userMapper.map(auth);

		assertThat(user.getUsername()).isEqualTo(UserTestFactory.USER_NAME);
	}

	@Test
	void shouldGetCompanyName() {
		var user = userMapper.map(auth);

		assertThat(user.getCompanyName()).isEqualTo(UserTestFactory.COMPANY_NAME);
	}

	@Test
	void shouldGetLegalForm() {
		var user = userMapper.map(auth);

		assertThat(user.getLegalForm()).isEqualTo(UserTestFactory.LEGAL_FORM);
	}

	@Test
	void shouldGetLegalFormText() {
		var user = userMapper.map(auth);

		assertThat(user.getLegalFormText()).isEqualTo(UserTestFactory.LEGAL_FORM_TEXT);
	}

	@Test
	void shouldGetRegisterNumber() {
		var user = userMapper.map(auth);

		assertThat(user.getRegisterNumber()).isEqualTo(UserTestFactory.REGISTER_NUMBER);
	}

	@Test
	void shouldGetRegisterType() {
		var user = userMapper.map(auth);

		assertThat(user.getRegisterType()).isEqualTo(UserTestFactory.REGISTER_TYPE);
	}

	@Test
	void shouldGetEmailAddress() {
		var user = userMapper.map(auth);

		assertThat(user.getEmailAddress()).isEqualTo(UserTestFactory.EMAIL_ADDRESS);
	}

	@Test
	void shouldGetAddress() {
		var user = userMapper.map(auth);

		assertThat(user.getAddress()).isEqualTo(UserTestFactory.ADDRESS);
	}

	@Test
	void shouldGetTrustLevel() {
		var user = userMapper.map(auth);

		assertThat(user.getTrustLevel()).isEqualTo(UserTestFactory.TRUST_LEVEL);
	}

	@Test
	void shouldGetUnknownAttributes() {
		var user = userMapper.map(auth);

		assertThat(user.getUnknownAttributes()).isEmpty();
	}

}