/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.security;

import java.time.Instant;
import java.time.temporal.ChronoUnit;
import java.util.UUID;

public class UserTestFactory {

	public static final String USER_ID = UUID.randomUUID().toString();
	public static final String USER_NAME = USER_ID;
	public static final String COMPANY_NAME = "Pauls Unternehmen";
	public static final String LEGAL_FORM = "123";
	public static final String LEGAL_FORM_TEXT = "AG";
	public static final String REGISTER_NUMBER = "123";
	public static final String REGISTER_TYPE = "ABC";
	public static final String EMAIL_ADDRESS = "paul.panter@test.com";
	public static final String STREET = "Musterstraße";
	public static final String HOUSE_NUMBER = "1";
	public static final String POSTAL_CODE = "11011";
	public static final String CITY = "Berlin";
	public static final String COUNTRY = "DE";
	public static final String ADDRESS = String.format("%s %s, %s %s, %s", STREET, HOUSE_NUMBER, POSTAL_CODE, CITY, COUNTRY);
	public static final String TRUST_LEVEL = "substantial";
	public static final String SAML_TOKEN = "samlToken";

	public static User create() {
		return createBuilder().build();
	}

	static User.UserBuilder createBuilder() {
		return new User.UserBuilder()
		  .id(USER_ID)
		  .username(USER_NAME)
		  .companyName(COMPANY_NAME)
		  .legalForm(LEGAL_FORM)
		  .legalFormText(LEGAL_FORM_TEXT)
		  .registerNumber(REGISTER_NUMBER)
		  .registerType(REGISTER_TYPE)
		  .emailAddress(EMAIL_ADDRESS)
		  .address(ADDRESS)
		  .trustLevel(TRUST_LEVEL)
		  .expirationDate(Instant.now().plus(4, ChronoUnit.HOURS));
	}

}
