/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class EingangMapperTest {

	@InjectMocks
	private final EingangMapper mapper = Mappers.getMapper(EingangMapper.class);

	@Mock
	private final AntragstellerMapper antragstellerMapper = Mappers.getMapper(AntragstellerMapper.class);

	@BeforeEach
	void init() {
		when(antragstellerMapper.toAntragsteller(any())).thenReturn(AntragstellerTestFactory.create());
	}

	@Test
	void shouldMap() {
		var eingang = mapper.toEingang(GrpcEingangTestFactory.create());

		assertThat(eingang).usingRecursiveComparison().ignoringFields("id").isEqualTo(EingangTestFactory.create());
	}

	@Test
	void shouldCallAntragstellerMapper() {
		mapper.toEingang(GrpcEingangTestFactory.create());

		verify(antragstellerMapper).toAntragsteller(GrpcAntragstellerTestFactory.create());
	}

}