/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;

@ExtendWith(MockitoExtension.class)
class VorgangControllerTest {

	@Spy
	@InjectMocks
	private VorgangController controller;

	@Mock
	private VorgangService vorgangService;

	@Mock
	private VorgangModelAssembler modelAssembler;

	@Nested
	class TestGetVorgang {

		private static final String COLLABORATION_MANAGER_ADDRESS = VorgangWithCollaborationManagerAddressTestFactory.COLLABORATION_MANAGER_ADDRESS;

		@BeforeEach
		void init() {
			var vorgangWithCollaborationManagerAddress = VorgangWithCollaborationManagerAddressTestFactory.create();

			when(vorgangService.findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS)).thenReturn(VorgangTestFactory.create());
			when(modelAssembler.toModel(vorgangWithCollaborationManagerAddress)).thenReturn(
			  EntityModel.of(vorgangWithCollaborationManagerAddress.vorgang()));
		}

		@Test
		void shouldCallVorgangService() {
			controller.getVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);

			verify(vorgangService).findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);
		}

		@Test
		void shouldCallAssembler() {
			controller.getVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);

			verify(modelAssembler).toModel(VorgangWithCollaborationManagerAddressTestFactory.create());
		}

		@Test
		void shouldHaveVorgangEntityModel() {
			assertThat(controller.getVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS)).isNotNull();
		}

		@Test
		void shouldHaveVorgang() {
			assertThat(controller.getVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS).getContent()).isEqualTo(
			  VorgangTestFactory.create());
		}

	}

	@Nested
	class TestGetAll {

		@Test
		void shouldHaveVorgaenge() {
			when(modelAssembler.toCollectionModel(any())).thenReturn(CollectionModel.of(List.of()));

			assertThat(controller.getAll().getContent()).isNotNull();
		}

	}

}