/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;
import org.springframework.hateoas.LinkRelation;

@ExtendWith(MockitoExtension.class)
class VorgangProcessorTest {

	@Spy
	private VorgangProcessor processor;

	@Nested
	@Disabled("Wird enabled, sobald Collaboration API für Kommentare existiert")
	class TestKommentareLink {

		@Test
		void shouldBePresent() {
			var link = processor.process(EntityModel.of(VorgangTestFactory.create())).getLink(VorgangProcessor.REL_KOMMENTARE);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo("/api/vorgangs/" + VorgangTestFactory.ID + "/kommentars");
		}

	}

	@Nested
	@Disabled("Wird enabled, sobald Collaboration API für Attachments existiert")
	class TestAttachmentLinks {

		@Nested
		class TestLink {

			private static final String PATH = "/api/attachments?eingangId=" + EingangTestFactory.ID;
			private final LinkRelation linkRel = VorgangProcessor.REL_ATTACHMENTS;

			@Test
			void shouldBePresent() {
				var link = processor.process(getVorgangWithAttachments(1)).getLink(linkRel);

				assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(PATH);
			}

			@Test
			void shouldNotBePresent() {
				var link = processor.process(getVorgangWithAttachments(0)).getLink(linkRel);

				assertThat(link).isNotPresent();
			}

		}

		@Nested
		class TestDownloadLink {

			private static final String PATH = "/api/vorgang/" + VorgangTestFactory.ID + "/attachments?eingangId=" + EingangTestFactory.ID;
			private final LinkRelation linkRel = VorgangProcessor.REL_DOWNLOAD_ATTACHMENTS;

			@Test
			void shouldBePresent() {
				var link = processor.process(getVorgangWithAttachments(1)).getLink(linkRel);

				assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(PATH);
			}

			@Test
			void shouldNotBePresent() {
				var link = processor.process(getVorgangWithAttachments(0)).getLink(linkRel);

				assertThat(link).isNotPresent();
			}

		}

		private EntityModel<Vorgang> getVorgangWithAttachments(int numberOfAttachments) {
			return EntityModel.of(VorgangTestFactory.createBuilder()
			  .eingang(EingangTestFactory.createBuilder()
				.numberOfAttachments(numberOfAttachments)
				.build())
			  .build());
		}

	}

	@Nested
	@Disabled("Wird enabled, sobald Collaboration API für Representations existiert")
	class TestRepresentationsLink {

		private static final String PATH = "/api/representations?eingangId=" + EingangTestFactory.ID;
		private final LinkRelation linkRel = VorgangProcessor.REL_REPRESENTATIONS;

		@Test
		void shouldBePresent() {
			var link = processor.process(getVorgangWithRepresentations(1)).getLink(linkRel);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo(PATH);
		}

		@Test
		void shouldNotBePresent() {
			var link = processor.process(getVorgangWithRepresentations(0)).getLink(linkRel);

			assertThat(link).isNotPresent();
		}

		private EntityModel<Vorgang> getVorgangWithRepresentations(int numberOfRepresentations) {
			return EntityModel.of(VorgangTestFactory.createBuilder()
			  .eingang(EingangTestFactory.createBuilder()
				.numberOfRepresentations(numberOfRepresentations)
				.build())
			  .build());
		}

	}

	@Nested
	@Disabled("Wird enabled, sobald Collaboration API für Commands existiert")
	class TestHistorieLink {

		@Test
		void shouldBePresent() {
			var link = processor.process(EntityModel.of(VorgangTestFactory.create())).getLink(VorgangProcessor.REL_HISTORIE);

			assertThat(link).isPresent().get().extracting(Link::getHref).isEqualTo("/api/histories?vorgangId=" + VorgangTestFactory.ID);
		}

	}

}