/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.fachstelle.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

@ExtendWith(MockitoExtension.class)
class VorgangServiceTest {

	@Spy
	@InjectMocks
	private VorgangService vorgangService;

	@Mock
	private VorgangRemoteService vorgangRemoteService;

	@Nested
	class TestFindVorgang {

		private static final String COLLABORATION_MANAGER_ADDRESS = VorgangWithCollaborationManagerAddressTestFactory.COLLABORATION_MANAGER_ADDRESS;

		@BeforeEach
		void init() {
			when(vorgangRemoteService.findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS)).thenReturn(VorgangTestFactory.create());
		}

		@Test
		void shouldCallVorgangRemoteService() {
			vorgangService.findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);

			verify(vorgangRemoteService).findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);
		}

		@Test
		void shouldGetVorgang() {
			var vorgang = vorgangService.findVorgang(VorgangTestFactory.ID, COLLABORATION_MANAGER_ADDRESS);

			assertThat(vorgang).usingRecursiveComparison().isEqualTo(VorgangTestFactory.create());
		}

	}

}